# Boost.Sync

Boost.Sync, part of collection of the [Boost C++ Libraries](https://github.com/boostorg), implements thread synchronization primitives.

## Directories

* **build** - Boost.Sync build scripts
* **doc** - QuickBook documentation sources
* **include** - Interface headers of Boost.Sync
* **src** - Compilable source code of Boost.Sync
* **test** - Boost.Sync unit tests

### More information

* [Documentation](https://boost.org/libs/sync)
* [Report bugs](https://github.com/boostorg/sync/issues/new). Be sure to mention Boost version, platform and compiler you're using. A small compilable code sample to reproduce the problem is always good as well.
* Submit your patches as pull requests against **develop** branch. Note that by submitting patches you agree to license your modifications under the [Boost Software License, Version 1.0](https://www.boost.org/LICENSE_1_0.txt).

### Build status

Master: [![AppVeyor](https://ci.appveyor.com/api/projects/status/x5m5lueci0iu4udr/branch/master?svg=true)](https://ci.appveyor.com/project/Lastique/sync/branch/master) [![Travis CI](https://travis-ci.org/boostorg/sync.svg?branch=master)](https://travis-ci.org/boostorg/sync)
Develop: [![AppVeyor](https://ci.appveyor.com/api/projects/status/x5m5lueci0iu4udr/branch/develop?svg=true)](https://ci.appveyor.com/project/Lastique/sync/branch/develop) [![Travis CI](https://travis-ci.org/boostorg/sync.svg?branch=develop)](https://travis-ci.org/boostorg/sync)

### License

Distributed under the [Boost Software License, Version 1.0](https://www.boost.org/LICENSE_1_0.txt).
